/*
 * Copyright 2021-2023 VMware, Inc.
 * SPDX-License-Identifier: Apache-2.0
 */

.jp-vdk-input-wrapper {
  display: flex;
  flex-direction: column;
  margin-top: 15px;
}

.hidden {
  display: none;
}

.jp-vdk-checkbox-wrappers {
  display: flex;
  justify-content: flex-start;
  align-items: center;
  margin-left: 0;
  padding-left: 0;
}

.jp-vdk-checkbox {
  margin-right: 10px;
}

#enable {
  margin-top: 10px;
  margin-left: 0;
}

.vdk-run-error-message {
  color: #c0392b;
  padding: 20px;
  font-weight: bold;
  display: flex;
  flex-direction: column;
  align-items: flex-start;
}

.vdk-run-error-message p {
  padding-bottom: 10px;
}

.vdk-run-error-message a {
  color: #11239a;
  text-decoration: underline;
}

.vdk-run-dialog-message {
  font-size: 20px;
  color: #33b53a;
  padding: 20px;
}
.vdk-run-dialog-message-container {
  position: relative;
}
