/*
 * Copyright 2021-2023 VMware, Inc.
 * SPDX-License-Identifier: Apache-2.0
 */

/**
 * Example of [Jest](https://jestjs.io/docs/getting-started) unit tests
 */

describe('vdk-jupyterlab-extension', () => {
  it('should be tested', () => {
    expect(1 + 1).toEqual(2);
  });
});
