/*
 * Copyright 2021-2023 VMware, Inc.
 * SPDX-License-Identifier: Apache-2.0
 */
/*
    See the JupyterLab Developer Guide for useful CSS Patterns:

    https://jupyterlab.readthedocs.io/en/stable/developer/css.html
*/
@import url('vdkDialogs.css');

.jp-vdk-cell {
  --jp-cell-editor-background: rgb(240 246 255);
}

.jp-vdk-cell-dark {
  --jp-cell-editor-background: rgb(6 27 59);
}

.jp-vdk-cell-num {
  position: absolute;
  top: 0;
  right: 0;
  background-color: #1e488c;
  color: aliceblue;
  padding: 4px;
}

.jp-vdk-logo {
  position: absolute;
  top: 0;
  right: -5px;
  padding-right: 25px;
}

.jp-vdk-failing-cell {
  --jp-cell-editor-border-color: #8c1e1e;
  --jp-cell-editor-box-shadow: inset 0 0 2px #8c1e1e;
}

.jp-vdk-failing-cell-num {
  position: absolute;
  top: 0;
  right: 0;
  background-color: #8c1e1e;
  color: aliceblue;
  padding: 4px;
}

.jp-vdk-failing-cell-prompt {
  --jp-cell-prompt-not-active-font-color: #8c1e1e;
  --jp-cell-inprompt-font-color: #8c1e1e;
}
